@@ -5,3 +5,5 @@ def load():
     import pyomo.contrib.preprocessing.plugins.remove_zero_terms
     import pyomo.contrib.preprocessing.plugins.equality_propagate
     import pyomo.contrib.preprocessing.plugins.strip_bounds
+    import pyomo.contrib.preprocessing.plugins.zero_sum_propagator
+    import pyomo.contrib.preprocessing.plugins.bounds_to_vars
