@@ -111,8 +111,9 @@ class _ParamData(ComponentData, NumericValue):
         if self._value is _NotValid:
             raise ValueError(
                 "Error evaluating Param value (%s):\n\tThe Param value is "
-                "currently set to an invalid value.\n\tThis is typically from "
-                "a scalar Param without an initial or default value."
+                "currently set to an invalid value.  This is\n\ttypically "
+                "from a scalar Param or mutable Indexed Param without\n"
+                "\tan initial or default value."
                 % ( self.name, ))
         return self._value
 
@@ -432,13 +433,20 @@ class Param(IndexedComponent):
         #
         val = self._default_val
         if val is _NotValid:
+            # We should allow the creation of mutable params without
+            # a default value, as long as *solving* a model without
+            # reasonable values produces an informative error.
+            if self._mutable:
+                # Note: _ParamData defaults to _NotValid
+                ans = self._data[index] = _ParamData(self)
+                return ans
             if self.is_indexed():
                 idx_str = '%s[%s]' % (self.name, index,)
             else:
                 idx_str = '%s' % (self.name,)
             raise ValueError(
-                "Error retrieving Param value (%s):\n\tThe Param value is "
-                "undefined and no default value is specified"
+                "Error retrieving immutable Param value (%s):\n\tThe Param "
+                "value is undefined and no default value is specified."
                 % ( idx_str,) )
 
         _default_type = type(val)
@@ -888,6 +896,10 @@ This has resulted in the conversion of the source to dense form.
             default = "(function)"
         else:
             default = str(self._default_val)
+        if self._mutable or not self.is_indexed():
+            dataGen = lambda k, v: [ v._value, ]
+        else:
+            dataGen = lambda k, v: [ v, ]
         return ( [("Size", len(self)),
                   ("Index", self._index if self.is_indexed() else None),
                   ("Domain", self.domain.name),
@@ -896,8 +908,7 @@ This has resulted in the conversion of the source to dense form.
                   ],
                  self.sparse_iteritems(),
                  ("Value",),
-                 lambda k, v: [ value(v)
-                                ]
+                 dataGen,
                  )
 
 
