@@ -25,7 +25,7 @@ from pyutilib.misc import flatten_tuple as pyutilib_misc_flatten_tuple
 
 from pyomo.util.timing import ConstructionTimer
 from pyomo.core.base.misc import apply_indexed_rule, \
-    apply_parameterized_indexed_rule
+    apply_parameterized_indexed_rule, sorted_robust
 from pyomo.core.base.plugin import register_component
 from pyomo.core.base.component import Component, ComponentData
 from pyomo.core.base.indexed_component import IndexedComponent, \
@@ -110,70 +110,20 @@ def simple_set_rule( fn ):
     return wrapper_function
 
 
-class _robust_sort_keys(object):
-    """Class for robustly generating sortable keys for arbitrary data.
-
-    Generates keys (for use with Python `sorted()` that are
-    (str(type_name), val), where val is the actual value (if the type
-    is comparable), otherwise is the string representation of the value.
-    If str() also fails, we fall back on id().
-
-    This allows sorting lists with mixed types in Python3
-
-    We implement this as a callable object so that we can store the
-    _typemap without resorting to global variables.
-
-    """
-    def __init__(self):
-        self._typemap = {}
-
-    def __call__(self, val):
-        """Generate a tuple ( str(type_name), val ) for sorting the value.
-
-        `key=` expects a function.  We are generating a functor so we
-        have a convenient place to store the _typemap, which converts
-        the type-specific functions for converting a value to the second
-        argument of the sort key.
-
-        """
-        _type = type(val)
-        if _type not in self._typemap:
-            # If this is not a type we have seen before, determine what
-            # to use for the second value in the tuple.
-            try:
-                # 1: Check if the type is comparable 
-                val < val
-                self._typemap[_type] = lambda x:x
-            except:
-                try:
-                    # 2: try converting the value to string
-                    str(val)
-                    self._typemap[_type] = lambda x:str(x)
-                except:
-                    # 3: fallback on id().  Not deterministic
-                    # (run-to-run), but at least is consistent within
-                    # this run.
-                    self._typemap[_type] = lambda x:id(x)
-        return _type.__name__, self._typemap[_type](val)
-
-
-
 def _value_sorter(self, obj):
     """Utility to sort the values of a Set.
 
     This returns the values of the Set in a consistent order.  For
     ordered Sets, simply return the ordered list.  For unordered Sets,
     first try the standard sorted order, and if that fails (for example
-    with mixed-type Sets in Python3), use the _robust_sorter utility
-    (above) to generate sortable keys.
+    with mixed-type Sets in Python3), use the sorted_robust utility to
+    generate sortable keys.
 
     """
     if self.ordered:
         return obj.value
-    try:
-        return sorted(obj)
-    except:
-        return sorted(obj, key=_robust_sort_keys())
+    else:
+        return sorted_robust(obj)
 
 
 # A trivial class that we can use to test if an object is a "legitimate"
