@@ -20,5 +20,3 @@ import pyomo.core.plugins.transform.radix_linearization
 import pyomo.core.plugins.transform.discrete_vars
 # import pyomo.core.plugins.transform.util
 import pyomo.core.plugins.transform.add_slack_vars
-import pyomo.core.plugins.transform.zero_sum_propagator
-import pyomo.core.plugins.transform.bounds_to_vars
