@@ -10,10 +10,14 @@
 
 import copy
 
-import pyutilib.th as unittest
-from pyomo.environ import *
 from six import StringIO
 
+import pyutilib.th as unittest
+from pyutilib.misc.redirect_io import capture_output
+
+from pyomo.environ import *
+from pyomo.core.base.expression import _GeneralExpressionData
+
 class TestExpressionData(unittest.TestCase):
 
     def test_exprdata_get_set(self):
@@ -330,17 +334,63 @@ class TestExpression(unittest.TestCase):
     def test_display(self):
         model = ConcreteModel()
         model.e = Expression()
-        model.e.display()
+        with capture_output() as out:
+            model.e.display()
+        self.assertEqual(out.getvalue().strip(), """
+e : Size=1
+    Key  : Value
+    None : Undefined
+        """.strip())
+
         model.e.set_value(1.0)
-        model.e.display()
+        with capture_output() as out:
+            model.e.display()
+        self.assertEqual(out.getvalue().strip(), """
+e : Size=1
+    Key  : Value
+    None :   1.0
+        """.strip())
+
         out = StringIO()
-        model.e.display(ostream=out)
+        with capture_output() as no_out:
+            model.e.display(ostream=out)
+        self.assertEqual(no_out.getvalue(), "")
+        self.assertEqual(out.getvalue().strip(), """
+e : Size=1
+    Key  : Value
+    None :   1.0
+        """.strip())
+
         model.E = Expression([1,2])
-        model.E.display()
+        with capture_output() as out:
+            model.E.display()
+        self.assertEqual(out.getvalue().strip(), """
+E : Size=2
+    Key : Value
+      1 : Undefined
+      2 : Undefined
+        """.strip())
+
         model.E[1].set_value(1.0)
-        model.E.display()
+        with capture_output() as out:
+            model.E.display()
+        self.assertEqual(out.getvalue().strip(), """
+E : Size=2
+    Key : Value
+      1 :       1.0
+      2 : Undefined
+        """.strip())
+
         out = StringIO()
-        model.E.display(ostream=out)
+        with capture_output() as no_out:
+            model.E.display(ostream=out)
+        self.assertEqual(no_out.getvalue(), "")
+        self.assertEqual(out.getvalue().strip(), """
+E : Size=2
+    Key : Value
+      1 :       1.0
+      2 : Undefined
+        """.strip())
 
     def test_extract_values_store_values(self):
         model = ConcreteModel()
@@ -436,8 +486,21 @@ class TestExpression(unittest.TestCase):
         self.assertEqual(model.E.extract_values(),
                          {2:2, 3:3})
         self.assertEqual(len(model.E), 2)
-        with self.assertRaises(KeyError):
-            model.E[1]
+
+    def test_implicit_definition(self):
+        model = ConcreteModel()
+        model.idx = Set(initialize=[1,2,3])
+        model.E = Expression(model.idx, rule=lambda m,i: Expression.Skip)
+        self.assertEqual(len(model.E), 0)
+        expr = model.E[1]
+        self.assertIs(type(expr), _GeneralExpressionData)
+        self.assertIs(expr.value, None)
+        model.E[1] = 5
+        self.assertIs(expr, model.E[1])
+        self.assertEqual(model.E.extract_values(), {1:5})
+        model.E[2] = 6
+        self.assertIsNot(expr, model.E[2])
+        self.assertEqual(model.E.extract_values(), {1:5, 2:6})
 
     def test_indexed_construct_expr(self):
         model = ConcreteModel()
