@@ -44,7 +44,9 @@ _packages = [
 _optional_packages = set([
     'pyomo.contrib.example',
     'pyomo.contrib.preprocessing',
-    'pyomo.contrib.gdpopt'])
+    'pyomo.contrib.gdpopt',
+    'pyomo.contrib.trustregion',
+])
 
 
 def _import_packages():
