@@ -35,7 +35,7 @@ from six import advance_iterator, iteritems, itervalues
 logger = logging.getLogger('pyomo.pysp')
 
 #
-# a specialized asynchronous action manager for the SPPyroScenarioTreeServer
+# a specialized asynchronous action manager for the scenariotreeserver
 #
 
 class ScenarioTreeActionManagerPyro(PyroAsynchronousActionManager):
@@ -51,6 +51,12 @@ class ScenarioTreeActionManagerPyro(PyroAsynchronousActionManager):
         # (it will still report them, just take no action)
         self.ignore_task_errors = False
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
+
     def close(self):
         """Close the manager."""
         if len(self.server_pool):
@@ -275,11 +281,14 @@ class ScenarioTreeActionManagerPyro(PyroAsynchronousActionManager):
                         raise RuntimeError(
                             "The %s found results for task with id=%s"
                             " - but no corresponding action handle "
-                            "could be located!" % (type(self).__name__, task['id']))
+                            "could be located! Showing task result "
+                            "below:\n%s" % (type(self).__name__,
+                                            task['id'],
+                                            task.get('result', None)))
                     if type(task['result']) is TaskProcessingError:
                         ah.status = ActionStatus.error
                         self.event_handle[ah.id].update(ah)
-                        msg = ("SPPyroScenarioTreeServer reported a processing "
+                        msg = ("ScenarioTreeServer reported a processing "
                                "error for task with id=%s. Reason: \n%s"
                                % (task['id'], task['result'].args[0]))
                         if not self.ignore_task_errors:
