@@ -579,14 +579,14 @@ class _ScenarioTreeManagerSolverTesterBase(object):
                 problem.validate_solve(self, sp, results, names=names)
             with self._init(problem.get_factory()) as sp:
                 with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                    job = manager.solve_scenarios(async=True,
+                    job = manager.solve_scenarios(async_call=True,
                                                   check_status=True,
                                                   scenarios=names)
                     results = job.complete()
                 problem.validate_solve(self, sp, results, names=names)
             with self._init(problem.get_factory()) as sp:
                 with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                    job = manager.solve_scenarios(async=True,
+                    job = manager.solve_scenarios(async_call=True,
                                                   check_status=False,
                                                   scenarios=names)
                     results = job.complete()
@@ -608,13 +608,13 @@ class _ScenarioTreeManagerSolverTesterBase(object):
                     manager.solve_scenarios(check_status=True)
         with self._init(problem.get_factory()) as sp:
             with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                job = manager.solve_scenarios(async=True,
+                job = manager.solve_scenarios(async_call=True,
                                               check_status=True)
                 with self.assertRaises(PySPFailedSolveStatus):
                     job.complete()
         with self._init(problem.get_factory()) as sp:
             with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                job = manager.solve_scenarios(async=True,
+                job = manager.solve_scenarios(async_call=True,
                                               check_status=False)
                 results = job.complete()
             problem.validate_solve(self, sp, results)
@@ -634,7 +634,7 @@ class _ScenarioTreeManagerSolverTesterBase(object):
                 problem.validate_solve(self, sp, results, names=names)
             with self._init(problem.get_factory()) as sp:
                 with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                    job = manager.solve_scenarios(async=True,
+                    job = manager.solve_scenarios(async_call=True,
                                                   check_status=False,
                                                   scenarios=names)
                     results = job.complete()
@@ -663,14 +663,14 @@ class _ScenarioTreeManagerSolverTesterBase(object):
                 problem.validate_solve(self, sp, results, names=names)
             with self._init(problem.get_factory()) as sp:
                 with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                    job = manager.solve_bundles(async=True,
+                    job = manager.solve_bundles(async_call=True,
                                                 check_status=True,
                                                 bundles=names)
                     results = job.complete()
                 problem.validate_solve(self, sp, results, names=names)
             with self._init(problem.get_factory()) as sp:
                 with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                    job = manager.solve_bundles(async=True,
+                    job = manager.solve_bundles(async_call=True,
                                                 check_status=False,
                                                 bundles=names)
                     results = job.complete()
@@ -688,13 +688,13 @@ class _ScenarioTreeManagerSolverTesterBase(object):
                     manager.solve_bundles(check_status=True)
         with self._init(problem.get_factory()) as sp:
             with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                job = manager.solve_bundles(async=True,
+                job = manager.solve_bundles(async_call=True,
                                             check_status=True)
                 with self.assertRaises(PySPFailedSolveStatus):
                     job.complete()
         with self._init(problem.get_factory()) as sp:
             with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                job = manager.solve_bundles(async=True,
+                job = manager.solve_bundles(async_call=True,
                                             check_status=False)
                 results = job.complete()
             problem.validate_solve(self, sp, results)
@@ -714,7 +714,7 @@ class _ScenarioTreeManagerSolverTesterBase(object):
                 problem.validate_solve(self, sp, results, names=names)
             with self._init(problem.get_factory()) as sp:
                 with ScenarioTreeManagerSolverFactory(sp, _default_test_options) as manager:
-                    job = manager.solve_bundles(async=True,
+                    job = manager.solve_bundles(async_call=True,
                                                 check_status=False,
                                                 bundles=names)
                     results = job.complete()
