@@ -16,15 +16,16 @@ import pyomo.solvers.plugins.solvers.GLPK
 import pyomo.solvers.plugins.solvers.GLPK_old
 import pyomo.solvers.plugins.solvers.glpk_direct
 import pyomo.solvers.plugins.solvers.CPLEX
-import pyomo.solvers.plugins.solvers.CPLEXDirect
-import pyomo.solvers.plugins.solvers.CPLEXPersistent
 import pyomo.solvers.plugins.solvers.GUROBI
 import pyomo.solvers.plugins.solvers.BARON
-import pyomo.solvers.plugins.solvers.gurobi_direct
 import pyomo.solvers.plugins.solvers.ASL
 import pyomo.solvers.plugins.solvers.pywrapper
 import pyomo.solvers.plugins.solvers.SCIPAMPL
 import pyomo.solvers.plugins.solvers.CONOPT
 import pyomo.solvers.plugins.solvers.XPRESS
 import pyomo.solvers.plugins.solvers.IPOPT
+import pyomo.solvers.plugins.solvers.gurobi_direct
+import pyomo.solvers.plugins.solvers.gurobi_persistent
+import pyomo.solvers.plugins.solvers.cplex_direct
+import pyomo.solvers.plugins.solvers.cplex_persistent
 import pyomo.solvers.plugins.solvers.GAMS
