@@ -8,10 +8,10 @@
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
+import pyomo.kernel as pmo
 from pyomo.core import ConcreteModel, Param, Var, Expression, Objective, Constraint, Integers, Binary, NonNegativeReals
 from pyomo.solvers.tests.models.base import _BaseTestModel, register_model
 
-
 @register_model
 class MILP_simple(_BaseTestModel):
     """
@@ -42,6 +42,21 @@ class MILP_simple(_BaseTestModel):
     def warmstart_model(self):
         assert self.model is not None
         model = self.model
-        model.x = 0.1
-        model.y = 0
+        model.x.value = 0.1
+        model.y.value = 0
 
+@register_model
+class MILP_simple_kernel(MILP_simple):
+
+    def _generate_model(self):
+        self.model = pmo.block()
+        model = self.model
+        model._name = self.description
+
+        model.a = pmo.parameter(value=1.0)
+        model.x = pmo.variable(domain=NonNegativeReals)
+        model.y = pmo.variable(domain=Binary)
+
+        model.obj = pmo.objective(model.x + 3.0*model.y)
+        model.c1 = pmo.constraint(model.a <= model.y)
+        model.c2 = pmo.constraint(2.0 <= model.x/model.a - model.y <= 10)
